#!/usr/bin/env python
import ConfigParser
import cStringIO
import subprocess
import sys
import re
import os

OLD_VERSIONS = 'releases/zope-3.4.0.cfg'
NEW_VERSIONS = 'releases/bluebream-1.0a2.cfg'

def get_package(old_versions=OLD_VERSIONS,
                new_versions=NEW_VERSIONS):
    cp = ConfigParser.ConfigParser()
    cp.read(old_versions)
    old_pkg_versions = cp._sections['versions']

    cp = ConfigParser.ConfigParser()
    cp.read(new_versions)
    new_pkg_versions = cp._sections['versions']
    for package, version in new_pkg_versions.items():
        if package not in old_pkg_versions:
            yield package, '0.0.0'
        else:
            yield package, old_pkg_versions[package]

def extract_changes(package, version):
    url = 'svn://svn.zope.org/repos/main/%s/trunk/CHANGES.txt' % package
    changes = subprocess.Popen(['svn', 'cat', url, package],
                               shell=False,
                               stderr=subprocess.PIPE,
                               stdout=subprocess.PIPE)
    changes.wait()
    if changes.returncode > 0:
        print changes.stderr.read()
    diff = open(os.path.join("releases", package+"-changes.txt"), 'w')
    underline = "="*len(package)
    diff.write(package)
    diff.write('\n')
    diff.write(underline)
    diff.write('\n\n')
    pattern_start = re.compile('\d+\.\d+\.\d+\s+.*\d\d\d\d.\d\d.\d\d.*')
    pattern_end = re.compile('%s\s+.*\d\d\d\d.\d\d.\d\d.*'%version)
    started = False
    for line in changes.stdout:
        if not started:
            if pattern_start.match(line):
                started = True
            else:
                continue
        if pattern_end.match(line):
            break
        else:
            diff.write(line)
    diff.close()

if __name__ == '__main__':
    for pkg in get_package():
        extract_changes(*pkg)



from zope.site.interfaces import IFolder
from zope.schema import TextLine
from zope.schema import Text

class ISampleApplication(IFolder):
    """The main application container."""

    name = TextLine(
        title=u"Name",
        description=u"Name of application.",
        default=u"",
        required=True)

    description = Text(
        title=u"Description",
        description=u"The name of application container.",
        default=u"",
        required=False)



from ConfigParser import SafeConfigParser
from prettytable import PrettyTable

def process_file(file_name):
    config_parser = SafeConfigParser()
    config_parser.read(file_name)
    versions = dict(config_parser.items('versions'))
    return versions
    
new = process_file('releases/bluebream-1.0a2.cfg')
old = process_file('releases/zope-3.4.0.cfg')

chart = PrettyTable(["Package Name", "Zope 3.4.0", "BlueBream 1.0.0"])
chart.set_field_align("Package Name", "l")
chart.set_padding_width(1)
chart.set_field_align("Zope 3.4.0", "l")
chart.set_padding_width(1)
chart.set_field_align("BlueBream 1.0.0", "l")
chart.set_padding_width(1)

data = []

for package, version in new.items():
    if package in old:
        data.append([package, old[package], version])
    else:
        data.append([package, '', version])

for row in data:
    chart.add_row(row)

chart.printt(hrules=1,sortby="Package Name")



from zope.browserpage import ViewPageTemplateFile
from zope.container.interfaces import INameChooser
from zope.formlib import form

from interfaces import ISampleApplication
from app import SampleApplication


class RootDefaultView(form.DisplayForm):

    __call__ = ViewPageTemplateFile('index.pt')


class AddSampleApplication(form.AddForm):

    form_fields = form.Fields(ISampleApplication)

    def createAndAdd(self, data):
        name = data['name']
        description = data.get('description')
        namechooser = INameChooser(self.context)
        app = SampleApplication()
        name = namechooser.chooseName(name, app)
        app.name = name
        app.description = description
        self.context[name] = app
        self.request.response.redirect(name)


class SampleApplicationDefaultView(form.DisplayForm):

    def __call__(self):
        return """Welcome to the Sample application"""




from zope.interface import implements
from zope.site.folder import Folder

from interfaces import ISampleApplication


class SampleApplication(Folder):

    implements(ISampleApplication)
    name = u""
    description = u""
